Documentation
¶
Overview ¶
Package mediabase_v1 is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- Constants
- Variables
- func RegisterMediabaseServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterMediabaseServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client MediabaseServiceClient) error
- func RegisterMediabaseServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterMediabaseServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server MediabaseServiceServer) error
- func RegisterMediabaseServiceServer(s grpc.ServiceRegistrar, srv MediabaseServiceServer)
- type CreateBucketRequest
- func (*CreateBucketRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateBucketRequest) GetBucketName() string
- func (x *CreateBucketRequest) GetIsPublic() bool
- func (*CreateBucketRequest) ProtoMessage()
- func (x *CreateBucketRequest) ProtoReflect() protoreflect.Message
- func (x *CreateBucketRequest) Reset()
- func (x *CreateBucketRequest) String() string
- func (m *CreateBucketRequest) Validate() error
- func (m *CreateBucketRequest) ValidateAll() error
- type CreateBucketRequestMultiError
- type CreateBucketRequestValidationError
- func (e CreateBucketRequestValidationError) Cause() error
- func (e CreateBucketRequestValidationError) Error() string
- func (e CreateBucketRequestValidationError) ErrorName() string
- func (e CreateBucketRequestValidationError) Field() string
- func (e CreateBucketRequestValidationError) Key() bool
- func (e CreateBucketRequestValidationError) Reason() string
- type CreateBucketResponse
- func (*CreateBucketResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateBucketResponse) GetSuccess() bool
- func (*CreateBucketResponse) ProtoMessage()
- func (x *CreateBucketResponse) ProtoReflect() protoreflect.Message
- func (x *CreateBucketResponse) Reset()
- func (x *CreateBucketResponse) String() string
- func (m *CreateBucketResponse) Validate() error
- func (m *CreateBucketResponse) ValidateAll() error
- type CreateBucketResponseMultiError
- type CreateBucketResponseValidationError
- func (e CreateBucketResponseValidationError) Cause() error
- func (e CreateBucketResponseValidationError) Error() string
- func (e CreateBucketResponseValidationError) ErrorName() string
- func (e CreateBucketResponseValidationError) Field() string
- func (e CreateBucketResponseValidationError) Key() bool
- func (e CreateBucketResponseValidationError) Reason() string
- type DeleteObjectRequest
- func (*DeleteObjectRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteObjectRequest) GetBucketName() string
- func (x *DeleteObjectRequest) GetObjectKey() string
- func (*DeleteObjectRequest) ProtoMessage()
- func (x *DeleteObjectRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteObjectRequest) Reset()
- func (x *DeleteObjectRequest) String() string
- func (m *DeleteObjectRequest) Validate() error
- func (m *DeleteObjectRequest) ValidateAll() error
- type DeleteObjectRequestMultiError
- type DeleteObjectRequestValidationError
- func (e DeleteObjectRequestValidationError) Cause() error
- func (e DeleteObjectRequestValidationError) Error() string
- func (e DeleteObjectRequestValidationError) ErrorName() string
- func (e DeleteObjectRequestValidationError) Field() string
- func (e DeleteObjectRequestValidationError) Key() bool
- func (e DeleteObjectRequestValidationError) Reason() string
- type DeleteObjectResponse
- func (*DeleteObjectResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteObjectResponse) GetSuccess() bool
- func (*DeleteObjectResponse) ProtoMessage()
- func (x *DeleteObjectResponse) ProtoReflect() protoreflect.Message
- func (x *DeleteObjectResponse) Reset()
- func (x *DeleteObjectResponse) String() string
- func (m *DeleteObjectResponse) Validate() error
- func (m *DeleteObjectResponse) ValidateAll() error
- type DeleteObjectResponseMultiError
- type DeleteObjectResponseValidationError
- func (e DeleteObjectResponseValidationError) Cause() error
- func (e DeleteObjectResponseValidationError) Error() string
- func (e DeleteObjectResponseValidationError) ErrorName() string
- func (e DeleteObjectResponseValidationError) Field() string
- func (e DeleteObjectResponseValidationError) Key() bool
- func (e DeleteObjectResponseValidationError) Reason() string
- type MediabaseServiceClient
- type MediabaseServiceServer
- type PingRequest
- func (*PingRequest) Descriptor() ([]byte, []int)deprecated
- func (x *PingRequest) GetMessage() string
- func (*PingRequest) ProtoMessage()
- func (x *PingRequest) ProtoReflect() protoreflect.Message
- func (x *PingRequest) Reset()
- func (x *PingRequest) String() string
- func (m *PingRequest) Validate() error
- func (m *PingRequest) ValidateAll() error
- type PingRequestMultiError
- type PingRequestValidationError
- func (e PingRequestValidationError) Cause() error
- func (e PingRequestValidationError) Error() string
- func (e PingRequestValidationError) ErrorName() string
- func (e PingRequestValidationError) Field() string
- func (e PingRequestValidationError) Key() bool
- func (e PingRequestValidationError) Reason() string
- type PingResponse
- func (*PingResponse) Descriptor() ([]byte, []int)deprecated
- func (x *PingResponse) GetMessage() string
- func (*PingResponse) ProtoMessage()
- func (x *PingResponse) ProtoReflect() protoreflect.Message
- func (x *PingResponse) Reset()
- func (x *PingResponse) String() string
- func (m *PingResponse) Validate() error
- func (m *PingResponse) ValidateAll() error
- type PingResponseMultiError
- type PingResponseValidationError
- func (e PingResponseValidationError) Cause() error
- func (e PingResponseValidationError) Error() string
- func (e PingResponseValidationError) ErrorName() string
- func (e PingResponseValidationError) Field() string
- func (e PingResponseValidationError) Key() bool
- func (e PingResponseValidationError) Reason() string
- type PresignDownloadRequest
- func (*PresignDownloadRequest) Descriptor() ([]byte, []int)deprecated
- func (x *PresignDownloadRequest) GetBucketName() string
- func (x *PresignDownloadRequest) GetObjectKey() string
- func (*PresignDownloadRequest) ProtoMessage()
- func (x *PresignDownloadRequest) ProtoReflect() protoreflect.Message
- func (x *PresignDownloadRequest) Reset()
- func (x *PresignDownloadRequest) String() string
- func (m *PresignDownloadRequest) Validate() error
- func (m *PresignDownloadRequest) ValidateAll() error
- type PresignDownloadRequestMultiError
- type PresignDownloadRequestValidationError
- func (e PresignDownloadRequestValidationError) Cause() error
- func (e PresignDownloadRequestValidationError) Error() string
- func (e PresignDownloadRequestValidationError) ErrorName() string
- func (e PresignDownloadRequestValidationError) Field() string
- func (e PresignDownloadRequestValidationError) Key() bool
- func (e PresignDownloadRequestValidationError) Reason() string
- type PresignDownloadResponse
- func (*PresignDownloadResponse) Descriptor() ([]byte, []int)deprecated
- func (x *PresignDownloadResponse) GetExpiresIn() int32
- func (x *PresignDownloadResponse) GetPresignedUrl() string
- func (*PresignDownloadResponse) ProtoMessage()
- func (x *PresignDownloadResponse) ProtoReflect() protoreflect.Message
- func (x *PresignDownloadResponse) Reset()
- func (x *PresignDownloadResponse) String() string
- func (m *PresignDownloadResponse) Validate() error
- func (m *PresignDownloadResponse) ValidateAll() error
- type PresignDownloadResponseMultiError
- type PresignDownloadResponseValidationError
- func (e PresignDownloadResponseValidationError) Cause() error
- func (e PresignDownloadResponseValidationError) Error() string
- func (e PresignDownloadResponseValidationError) ErrorName() string
- func (e PresignDownloadResponseValidationError) Field() string
- func (e PresignDownloadResponseValidationError) Key() bool
- func (e PresignDownloadResponseValidationError) Reason() string
- type PresignUploadRequest
- func (*PresignUploadRequest) Descriptor() ([]byte, []int)deprecated
- func (x *PresignUploadRequest) GetBucketName() string
- func (x *PresignUploadRequest) GetContentType() string
- func (x *PresignUploadRequest) GetFileName() string
- func (x *PresignUploadRequest) GetMaxFileSize() int64
- func (x *PresignUploadRequest) GetPath() string
- func (*PresignUploadRequest) ProtoMessage()
- func (x *PresignUploadRequest) ProtoReflect() protoreflect.Message
- func (x *PresignUploadRequest) Reset()
- func (x *PresignUploadRequest) String() string
- func (m *PresignUploadRequest) Validate() error
- func (m *PresignUploadRequest) ValidateAll() error
- type PresignUploadRequestMultiError
- type PresignUploadRequestValidationError
- func (e PresignUploadRequestValidationError) Cause() error
- func (e PresignUploadRequestValidationError) Error() string
- func (e PresignUploadRequestValidationError) ErrorName() string
- func (e PresignUploadRequestValidationError) Field() string
- func (e PresignUploadRequestValidationError) Key() bool
- func (e PresignUploadRequestValidationError) Reason() string
- type PresignUploadResponse
- func (*PresignUploadResponse) Descriptor() ([]byte, []int)deprecated
- func (x *PresignUploadResponse) GetExpiresIn() int32
- func (x *PresignUploadResponse) GetFormData() map[string]string
- func (x *PresignUploadResponse) GetObjectKey() string
- func (x *PresignUploadResponse) GetPresignedUrl() string
- func (*PresignUploadResponse) ProtoMessage()
- func (x *PresignUploadResponse) ProtoReflect() protoreflect.Message
- func (x *PresignUploadResponse) Reset()
- func (x *PresignUploadResponse) String() string
- func (m *PresignUploadResponse) Validate() error
- func (m *PresignUploadResponse) ValidateAll() error
- type PresignUploadResponseMultiError
- type PresignUploadResponseValidationError
- func (e PresignUploadResponseValidationError) Cause() error
- func (e PresignUploadResponseValidationError) Error() string
- func (e PresignUploadResponseValidationError) ErrorName() string
- func (e PresignUploadResponseValidationError) Field() string
- func (e PresignUploadResponseValidationError) Key() bool
- func (e PresignUploadResponseValidationError) Reason() string
- type UnimplementedMediabaseServiceServer
- func (UnimplementedMediabaseServiceServer) CreateBucket(context.Context, *CreateBucketRequest) (*CreateBucketResponse, error)
- func (UnimplementedMediabaseServiceServer) DeleteObject(context.Context, *DeleteObjectRequest) (*DeleteObjectResponse, error)
- func (UnimplementedMediabaseServiceServer) Ping(context.Context, *PingRequest) (*PingResponse, error)
- func (UnimplementedMediabaseServiceServer) PresignDownload(context.Context, *PresignDownloadRequest) (*PresignDownloadResponse, error)
- func (UnimplementedMediabaseServiceServer) PresignUpload(context.Context, *PresignUploadRequest) (*PresignUploadResponse, error)
- type UnsafeMediabaseServiceServer
Constants ¶
const ( MediabaseService_Ping_FullMethodName = "/v1.MediabaseService/Ping" MediabaseService_PresignUpload_FullMethodName = "/v1.MediabaseService/PresignUpload" MediabaseService_PresignDownload_FullMethodName = "/v1.MediabaseService/PresignDownload" MediabaseService_DeleteObject_FullMethodName = "/v1.MediabaseService/DeleteObject" MediabaseService_CreateBucket_FullMethodName = "/v1.MediabaseService/CreateBucket" )
Variables ¶
var File_proto_mediabase_v1_mediabase_proto protoreflect.FileDescriptor
var File_proto_mediabase_v1_ping_proto protoreflect.FileDescriptor
var MediabaseService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "v1.MediabaseService", HandlerType: (*MediabaseServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Ping", Handler: _MediabaseService_Ping_Handler, }, { MethodName: "PresignUpload", Handler: _MediabaseService_PresignUpload_Handler, }, { MethodName: "PresignDownload", Handler: _MediabaseService_PresignDownload_Handler, }, { MethodName: "DeleteObject", Handler: _MediabaseService_DeleteObject_Handler, }, { MethodName: "CreateBucket", Handler: _MediabaseService_CreateBucket_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "proto/mediabase/v1/mediabase.proto", }
MediabaseService_ServiceDesc is the grpc.ServiceDesc for MediabaseService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterMediabaseServiceHandler ¶
func RegisterMediabaseServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterMediabaseServiceHandler registers the http handlers for service MediabaseService to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterMediabaseServiceHandlerClient ¶
func RegisterMediabaseServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client MediabaseServiceClient) error
RegisterMediabaseServiceHandlerClient registers the http handlers for service MediabaseService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "MediabaseServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "MediabaseServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "MediabaseServiceClient" to call the correct interceptors. This client ignores the HTTP middlewares.
func RegisterMediabaseServiceHandlerFromEndpoint ¶
func RegisterMediabaseServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterMediabaseServiceHandlerFromEndpoint is same as RegisterMediabaseServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterMediabaseServiceHandlerServer ¶
func RegisterMediabaseServiceHandlerServer(ctx context.Context, mux *runtime.ServeMux, server MediabaseServiceServer) error
RegisterMediabaseServiceHandlerServer registers the http handlers for service MediabaseService to "mux". UnaryRPC :call MediabaseServiceServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterMediabaseServiceHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.
func RegisterMediabaseServiceServer ¶
func RegisterMediabaseServiceServer(s grpc.ServiceRegistrar, srv MediabaseServiceServer)
Types ¶
type CreateBucketRequest ¶
type CreateBucketRequest struct {
BucketName string `protobuf:"bytes,1,opt,name=bucket_name,json=bucketName,proto3" json:"bucket_name,omitempty"`
IsPublic bool `protobuf:"varint,2,opt,name=is_public,json=isPublic,proto3" json:"is_public,omitempty"`
// contains filtered or unexported fields
}
CreateBucketRequest contains the bucket name and public access preference
func (*CreateBucketRequest) Descriptor
deprecated
func (*CreateBucketRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateBucketRequest.ProtoReflect.Descriptor instead.
func (*CreateBucketRequest) GetBucketName ¶
func (x *CreateBucketRequest) GetBucketName() string
func (*CreateBucketRequest) GetIsPublic ¶
func (x *CreateBucketRequest) GetIsPublic() bool
func (*CreateBucketRequest) ProtoMessage ¶
func (*CreateBucketRequest) ProtoMessage()
func (*CreateBucketRequest) ProtoReflect ¶
func (x *CreateBucketRequest) ProtoReflect() protoreflect.Message
func (*CreateBucketRequest) Reset ¶
func (x *CreateBucketRequest) Reset()
func (*CreateBucketRequest) String ¶
func (x *CreateBucketRequest) String() string
func (*CreateBucketRequest) Validate ¶
func (m *CreateBucketRequest) Validate() error
Validate checks the field values on CreateBucketRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*CreateBucketRequest) ValidateAll ¶
func (m *CreateBucketRequest) ValidateAll() error
ValidateAll checks the field values on CreateBucketRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in CreateBucketRequestMultiError, or nil if none found.
type CreateBucketRequestMultiError ¶
type CreateBucketRequestMultiError []error
CreateBucketRequestMultiError is an error wrapping multiple validation errors returned by CreateBucketRequest.ValidateAll() if the designated constraints aren't met.
func (CreateBucketRequestMultiError) AllErrors ¶
func (m CreateBucketRequestMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (CreateBucketRequestMultiError) Error ¶
func (m CreateBucketRequestMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type CreateBucketRequestValidationError ¶
type CreateBucketRequestValidationError struct {
// contains filtered or unexported fields
}
CreateBucketRequestValidationError is the validation error returned by CreateBucketRequest.Validate if the designated constraints aren't met.
func (CreateBucketRequestValidationError) Cause ¶
func (e CreateBucketRequestValidationError) Cause() error
Cause function returns cause value.
func (CreateBucketRequestValidationError) Error ¶
func (e CreateBucketRequestValidationError) Error() string
Error satisfies the builtin error interface
func (CreateBucketRequestValidationError) ErrorName ¶
func (e CreateBucketRequestValidationError) ErrorName() string
ErrorName returns error name.
func (CreateBucketRequestValidationError) Field ¶
func (e CreateBucketRequestValidationError) Field() string
Field function returns field value.
func (CreateBucketRequestValidationError) Key ¶
func (e CreateBucketRequestValidationError) Key() bool
Key function returns key value.
func (CreateBucketRequestValidationError) Reason ¶
func (e CreateBucketRequestValidationError) Reason() string
Reason function returns reason value.
type CreateBucketResponse ¶
type CreateBucketResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
// contains filtered or unexported fields
}
CreateBucketResponse indicates successful creation
func (*CreateBucketResponse) Descriptor
deprecated
func (*CreateBucketResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateBucketResponse.ProtoReflect.Descriptor instead.
func (*CreateBucketResponse) GetSuccess ¶
func (x *CreateBucketResponse) GetSuccess() bool
func (*CreateBucketResponse) ProtoMessage ¶
func (*CreateBucketResponse) ProtoMessage()
func (*CreateBucketResponse) ProtoReflect ¶
func (x *CreateBucketResponse) ProtoReflect() protoreflect.Message
func (*CreateBucketResponse) Reset ¶
func (x *CreateBucketResponse) Reset()
func (*CreateBucketResponse) String ¶
func (x *CreateBucketResponse) String() string
func (*CreateBucketResponse) Validate ¶
func (m *CreateBucketResponse) Validate() error
Validate checks the field values on CreateBucketResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*CreateBucketResponse) ValidateAll ¶
func (m *CreateBucketResponse) ValidateAll() error
ValidateAll checks the field values on CreateBucketResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in CreateBucketResponseMultiError, or nil if none found.
type CreateBucketResponseMultiError ¶
type CreateBucketResponseMultiError []error
CreateBucketResponseMultiError is an error wrapping multiple validation errors returned by CreateBucketResponse.ValidateAll() if the designated constraints aren't met.
func (CreateBucketResponseMultiError) AllErrors ¶
func (m CreateBucketResponseMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (CreateBucketResponseMultiError) Error ¶
func (m CreateBucketResponseMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type CreateBucketResponseValidationError ¶
type CreateBucketResponseValidationError struct {
// contains filtered or unexported fields
}
CreateBucketResponseValidationError is the validation error returned by CreateBucketResponse.Validate if the designated constraints aren't met.
func (CreateBucketResponseValidationError) Cause ¶
func (e CreateBucketResponseValidationError) Cause() error
Cause function returns cause value.
func (CreateBucketResponseValidationError) Error ¶
func (e CreateBucketResponseValidationError) Error() string
Error satisfies the builtin error interface
func (CreateBucketResponseValidationError) ErrorName ¶
func (e CreateBucketResponseValidationError) ErrorName() string
ErrorName returns error name.
func (CreateBucketResponseValidationError) Field ¶
func (e CreateBucketResponseValidationError) Field() string
Field function returns field value.
func (CreateBucketResponseValidationError) Key ¶
func (e CreateBucketResponseValidationError) Key() bool
Key function returns key value.
func (CreateBucketResponseValidationError) Reason ¶
func (e CreateBucketResponseValidationError) Reason() string
Reason function returns reason value.
type DeleteObjectRequest ¶
type DeleteObjectRequest struct {
// Bucket name where the file is stored
BucketName string `protobuf:"bytes,1,opt,name=bucket_name,json=bucketName,proto3" json:"bucket_name,omitempty"`
// Object key/path in storage
ObjectKey string `protobuf:"bytes,2,opt,name=object_key,json=objectKey,proto3" json:"object_key,omitempty"`
// contains filtered or unexported fields
}
DeleteObjectRequest contains the object key to delete
func (*DeleteObjectRequest) Descriptor
deprecated
func (*DeleteObjectRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteObjectRequest.ProtoReflect.Descriptor instead.
func (*DeleteObjectRequest) GetBucketName ¶
func (x *DeleteObjectRequest) GetBucketName() string
func (*DeleteObjectRequest) GetObjectKey ¶
func (x *DeleteObjectRequest) GetObjectKey() string
func (*DeleteObjectRequest) ProtoMessage ¶
func (*DeleteObjectRequest) ProtoMessage()
func (*DeleteObjectRequest) ProtoReflect ¶
func (x *DeleteObjectRequest) ProtoReflect() protoreflect.Message
func (*DeleteObjectRequest) Reset ¶
func (x *DeleteObjectRequest) Reset()
func (*DeleteObjectRequest) String ¶
func (x *DeleteObjectRequest) String() string
func (*DeleteObjectRequest) Validate ¶
func (m *DeleteObjectRequest) Validate() error
Validate checks the field values on DeleteObjectRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*DeleteObjectRequest) ValidateAll ¶
func (m *DeleteObjectRequest) ValidateAll() error
ValidateAll checks the field values on DeleteObjectRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in DeleteObjectRequestMultiError, or nil if none found.
type DeleteObjectRequestMultiError ¶
type DeleteObjectRequestMultiError []error
DeleteObjectRequestMultiError is an error wrapping multiple validation errors returned by DeleteObjectRequest.ValidateAll() if the designated constraints aren't met.
func (DeleteObjectRequestMultiError) AllErrors ¶
func (m DeleteObjectRequestMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (DeleteObjectRequestMultiError) Error ¶
func (m DeleteObjectRequestMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type DeleteObjectRequestValidationError ¶
type DeleteObjectRequestValidationError struct {
// contains filtered or unexported fields
}
DeleteObjectRequestValidationError is the validation error returned by DeleteObjectRequest.Validate if the designated constraints aren't met.
func (DeleteObjectRequestValidationError) Cause ¶
func (e DeleteObjectRequestValidationError) Cause() error
Cause function returns cause value.
func (DeleteObjectRequestValidationError) Error ¶
func (e DeleteObjectRequestValidationError) Error() string
Error satisfies the builtin error interface
func (DeleteObjectRequestValidationError) ErrorName ¶
func (e DeleteObjectRequestValidationError) ErrorName() string
ErrorName returns error name.
func (DeleteObjectRequestValidationError) Field ¶
func (e DeleteObjectRequestValidationError) Field() string
Field function returns field value.
func (DeleteObjectRequestValidationError) Key ¶
func (e DeleteObjectRequestValidationError) Key() bool
Key function returns key value.
func (DeleteObjectRequestValidationError) Reason ¶
func (e DeleteObjectRequestValidationError) Reason() string
Reason function returns reason value.
type DeleteObjectResponse ¶
type DeleteObjectResponse struct {
// Whether the deletion was successful
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
// contains filtered or unexported fields
}
DeleteObjectResponse indicates successful deletion
func (*DeleteObjectResponse) Descriptor
deprecated
func (*DeleteObjectResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteObjectResponse.ProtoReflect.Descriptor instead.
func (*DeleteObjectResponse) GetSuccess ¶
func (x *DeleteObjectResponse) GetSuccess() bool
func (*DeleteObjectResponse) ProtoMessage ¶
func (*DeleteObjectResponse) ProtoMessage()
func (*DeleteObjectResponse) ProtoReflect ¶
func (x *DeleteObjectResponse) ProtoReflect() protoreflect.Message
func (*DeleteObjectResponse) Reset ¶
func (x *DeleteObjectResponse) Reset()
func (*DeleteObjectResponse) String ¶
func (x *DeleteObjectResponse) String() string
func (*DeleteObjectResponse) Validate ¶
func (m *DeleteObjectResponse) Validate() error
Validate checks the field values on DeleteObjectResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*DeleteObjectResponse) ValidateAll ¶
func (m *DeleteObjectResponse) ValidateAll() error
ValidateAll checks the field values on DeleteObjectResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in DeleteObjectResponseMultiError, or nil if none found.
type DeleteObjectResponseMultiError ¶
type DeleteObjectResponseMultiError []error
DeleteObjectResponseMultiError is an error wrapping multiple validation errors returned by DeleteObjectResponse.ValidateAll() if the designated constraints aren't met.
func (DeleteObjectResponseMultiError) AllErrors ¶
func (m DeleteObjectResponseMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (DeleteObjectResponseMultiError) Error ¶
func (m DeleteObjectResponseMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type DeleteObjectResponseValidationError ¶
type DeleteObjectResponseValidationError struct {
// contains filtered or unexported fields
}
DeleteObjectResponseValidationError is the validation error returned by DeleteObjectResponse.Validate if the designated constraints aren't met.
func (DeleteObjectResponseValidationError) Cause ¶
func (e DeleteObjectResponseValidationError) Cause() error
Cause function returns cause value.
func (DeleteObjectResponseValidationError) Error ¶
func (e DeleteObjectResponseValidationError) Error() string
Error satisfies the builtin error interface
func (DeleteObjectResponseValidationError) ErrorName ¶
func (e DeleteObjectResponseValidationError) ErrorName() string
ErrorName returns error name.
func (DeleteObjectResponseValidationError) Field ¶
func (e DeleteObjectResponseValidationError) Field() string
Field function returns field value.
func (DeleteObjectResponseValidationError) Key ¶
func (e DeleteObjectResponseValidationError) Key() bool
Key function returns key value.
func (DeleteObjectResponseValidationError) Reason ¶
func (e DeleteObjectResponseValidationError) Reason() string
Reason function returns reason value.
type MediabaseServiceClient ¶
type MediabaseServiceClient interface {
// Ping is a simple GET request that returns a Pong message.
Ping(ctx context.Context, in *PingRequest, opts ...grpc.CallOption) (*PingResponse, error)
// PresignUpload generates a presigned URL for uploading a file
PresignUpload(ctx context.Context, in *PresignUploadRequest, opts ...grpc.CallOption) (*PresignUploadResponse, error)
// PresignDownload generates a presigned URL for downloading a file
PresignDownload(ctx context.Context, in *PresignDownloadRequest, opts ...grpc.CallOption) (*PresignDownloadResponse, error)
// DeleteObject deletes a file from storage
DeleteObject(ctx context.Context, in *DeleteObjectRequest, opts ...grpc.CallOption) (*DeleteObjectResponse, error)
// CreateBucket creates a bucket and optionally sets it to public read
CreateBucket(ctx context.Context, in *CreateBucketRequest, opts ...grpc.CallOption) (*CreateBucketResponse, error)
}
MediabaseServiceClient is the client API for MediabaseService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewMediabaseServiceClient ¶
func NewMediabaseServiceClient(cc grpc.ClientConnInterface) MediabaseServiceClient
type MediabaseServiceServer ¶
type MediabaseServiceServer interface {
// Ping is a simple GET request that returns a Pong message.
Ping(context.Context, *PingRequest) (*PingResponse, error)
// PresignUpload generates a presigned URL for uploading a file
PresignUpload(context.Context, *PresignUploadRequest) (*PresignUploadResponse, error)
// PresignDownload generates a presigned URL for downloading a file
PresignDownload(context.Context, *PresignDownloadRequest) (*PresignDownloadResponse, error)
// DeleteObject deletes a file from storage
DeleteObject(context.Context, *DeleteObjectRequest) (*DeleteObjectResponse, error)
// CreateBucket creates a bucket and optionally sets it to public read
CreateBucket(context.Context, *CreateBucketRequest) (*CreateBucketResponse, error)
// contains filtered or unexported methods
}
MediabaseServiceServer is the server API for MediabaseService service. All implementations must embed UnimplementedMediabaseServiceServer for forward compatibility.
type PingRequest ¶
type PingRequest struct {
// Message must be non-empty and between 1-100 characters
Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
PingRequest is the request message for the Ping RPC method.
func (*PingRequest) Descriptor
deprecated
func (*PingRequest) Descriptor() ([]byte, []int)
Deprecated: Use PingRequest.ProtoReflect.Descriptor instead.
func (*PingRequest) GetMessage ¶
func (x *PingRequest) GetMessage() string
func (*PingRequest) ProtoMessage ¶
func (*PingRequest) ProtoMessage()
func (*PingRequest) ProtoReflect ¶
func (x *PingRequest) ProtoReflect() protoreflect.Message
func (*PingRequest) Reset ¶
func (x *PingRequest) Reset()
func (*PingRequest) String ¶
func (x *PingRequest) String() string
func (*PingRequest) Validate ¶
func (m *PingRequest) Validate() error
Validate checks the field values on PingRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*PingRequest) ValidateAll ¶
func (m *PingRequest) ValidateAll() error
ValidateAll checks the field values on PingRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in PingRequestMultiError, or nil if none found.
type PingRequestMultiError ¶
type PingRequestMultiError []error
PingRequestMultiError is an error wrapping multiple validation errors returned by PingRequest.ValidateAll() if the designated constraints aren't met.
func (PingRequestMultiError) AllErrors ¶
func (m PingRequestMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (PingRequestMultiError) Error ¶
func (m PingRequestMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type PingRequestValidationError ¶
type PingRequestValidationError struct {
// contains filtered or unexported fields
}
PingRequestValidationError is the validation error returned by PingRequest.Validate if the designated constraints aren't met.
func (PingRequestValidationError) Cause ¶
func (e PingRequestValidationError) Cause() error
Cause function returns cause value.
func (PingRequestValidationError) Error ¶
func (e PingRequestValidationError) Error() string
Error satisfies the builtin error interface
func (PingRequestValidationError) ErrorName ¶
func (e PingRequestValidationError) ErrorName() string
ErrorName returns error name.
func (PingRequestValidationError) Field ¶
func (e PingRequestValidationError) Field() string
Field function returns field value.
func (PingRequestValidationError) Key ¶
func (e PingRequestValidationError) Key() bool
Key function returns key value.
func (PingRequestValidationError) Reason ¶
func (e PingRequestValidationError) Reason() string
Reason function returns reason value.
type PingResponse ¶
type PingResponse struct {
Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
PingResponse is the response message for the Ping RPC method.
func (*PingResponse) Descriptor
deprecated
func (*PingResponse) Descriptor() ([]byte, []int)
Deprecated: Use PingResponse.ProtoReflect.Descriptor instead.
func (*PingResponse) GetMessage ¶
func (x *PingResponse) GetMessage() string
func (*PingResponse) ProtoMessage ¶
func (*PingResponse) ProtoMessage()
func (*PingResponse) ProtoReflect ¶
func (x *PingResponse) ProtoReflect() protoreflect.Message
func (*PingResponse) Reset ¶
func (x *PingResponse) Reset()
func (*PingResponse) String ¶
func (x *PingResponse) String() string
func (*PingResponse) Validate ¶
func (m *PingResponse) Validate() error
Validate checks the field values on PingResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*PingResponse) ValidateAll ¶
func (m *PingResponse) ValidateAll() error
ValidateAll checks the field values on PingResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in PingResponseMultiError, or nil if none found.
type PingResponseMultiError ¶
type PingResponseMultiError []error
PingResponseMultiError is an error wrapping multiple validation errors returned by PingResponse.ValidateAll() if the designated constraints aren't met.
func (PingResponseMultiError) AllErrors ¶
func (m PingResponseMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (PingResponseMultiError) Error ¶
func (m PingResponseMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type PingResponseValidationError ¶
type PingResponseValidationError struct {
// contains filtered or unexported fields
}
PingResponseValidationError is the validation error returned by PingResponse.Validate if the designated constraints aren't met.
func (PingResponseValidationError) Cause ¶
func (e PingResponseValidationError) Cause() error
Cause function returns cause value.
func (PingResponseValidationError) Error ¶
func (e PingResponseValidationError) Error() string
Error satisfies the builtin error interface
func (PingResponseValidationError) ErrorName ¶
func (e PingResponseValidationError) ErrorName() string
ErrorName returns error name.
func (PingResponseValidationError) Field ¶
func (e PingResponseValidationError) Field() string
Field function returns field value.
func (PingResponseValidationError) Key ¶
func (e PingResponseValidationError) Key() bool
Key function returns key value.
func (PingResponseValidationError) Reason ¶
func (e PingResponseValidationError) Reason() string
Reason function returns reason value.
type PresignDownloadRequest ¶
type PresignDownloadRequest struct {
// Bucket name where the file is stored
BucketName string `protobuf:"bytes,1,opt,name=bucket_name,json=bucketName,proto3" json:"bucket_name,omitempty"`
// Object key/path in storage
ObjectKey string `protobuf:"bytes,2,opt,name=object_key,json=objectKey,proto3" json:"object_key,omitempty"`
// contains filtered or unexported fields
}
PresignDownloadRequest contains the object key for download
func (*PresignDownloadRequest) Descriptor
deprecated
func (*PresignDownloadRequest) Descriptor() ([]byte, []int)
Deprecated: Use PresignDownloadRequest.ProtoReflect.Descriptor instead.
func (*PresignDownloadRequest) GetBucketName ¶
func (x *PresignDownloadRequest) GetBucketName() string
func (*PresignDownloadRequest) GetObjectKey ¶
func (x *PresignDownloadRequest) GetObjectKey() string
func (*PresignDownloadRequest) ProtoMessage ¶
func (*PresignDownloadRequest) ProtoMessage()
func (*PresignDownloadRequest) ProtoReflect ¶
func (x *PresignDownloadRequest) ProtoReflect() protoreflect.Message
func (*PresignDownloadRequest) Reset ¶
func (x *PresignDownloadRequest) Reset()
func (*PresignDownloadRequest) String ¶
func (x *PresignDownloadRequest) String() string
func (*PresignDownloadRequest) Validate ¶
func (m *PresignDownloadRequest) Validate() error
Validate checks the field values on PresignDownloadRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*PresignDownloadRequest) ValidateAll ¶
func (m *PresignDownloadRequest) ValidateAll() error
ValidateAll checks the field values on PresignDownloadRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in PresignDownloadRequestMultiError, or nil if none found.
type PresignDownloadRequestMultiError ¶
type PresignDownloadRequestMultiError []error
PresignDownloadRequestMultiError is an error wrapping multiple validation errors returned by PresignDownloadRequest.ValidateAll() if the designated constraints aren't met.
func (PresignDownloadRequestMultiError) AllErrors ¶
func (m PresignDownloadRequestMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (PresignDownloadRequestMultiError) Error ¶
func (m PresignDownloadRequestMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type PresignDownloadRequestValidationError ¶
type PresignDownloadRequestValidationError struct {
// contains filtered or unexported fields
}
PresignDownloadRequestValidationError is the validation error returned by PresignDownloadRequest.Validate if the designated constraints aren't met.
func (PresignDownloadRequestValidationError) Cause ¶
func (e PresignDownloadRequestValidationError) Cause() error
Cause function returns cause value.
func (PresignDownloadRequestValidationError) Error ¶
func (e PresignDownloadRequestValidationError) Error() string
Error satisfies the builtin error interface
func (PresignDownloadRequestValidationError) ErrorName ¶
func (e PresignDownloadRequestValidationError) ErrorName() string
ErrorName returns error name.
func (PresignDownloadRequestValidationError) Field ¶
func (e PresignDownloadRequestValidationError) Field() string
Field function returns field value.
func (PresignDownloadRequestValidationError) Key ¶
func (e PresignDownloadRequestValidationError) Key() bool
Key function returns key value.
func (PresignDownloadRequestValidationError) Reason ¶
func (e PresignDownloadRequestValidationError) Reason() string
Reason function returns reason value.
type PresignDownloadResponse ¶
type PresignDownloadResponse struct {
// Presigned URL for downloading the file
PresignedUrl string `protobuf:"bytes,1,opt,name=presigned_url,json=presignedUrl,proto3" json:"presigned_url,omitempty"`
// Expiration time in seconds
ExpiresIn int32 `protobuf:"varint,2,opt,name=expires_in,json=expiresIn,proto3" json:"expires_in,omitempty"`
// contains filtered or unexported fields
}
PresignDownloadResponse contains the presigned download URL
func (*PresignDownloadResponse) Descriptor
deprecated
func (*PresignDownloadResponse) Descriptor() ([]byte, []int)
Deprecated: Use PresignDownloadResponse.ProtoReflect.Descriptor instead.
func (*PresignDownloadResponse) GetExpiresIn ¶
func (x *PresignDownloadResponse) GetExpiresIn() int32
func (*PresignDownloadResponse) GetPresignedUrl ¶
func (x *PresignDownloadResponse) GetPresignedUrl() string
func (*PresignDownloadResponse) ProtoMessage ¶
func (*PresignDownloadResponse) ProtoMessage()
func (*PresignDownloadResponse) ProtoReflect ¶
func (x *PresignDownloadResponse) ProtoReflect() protoreflect.Message
func (*PresignDownloadResponse) Reset ¶
func (x *PresignDownloadResponse) Reset()
func (*PresignDownloadResponse) String ¶
func (x *PresignDownloadResponse) String() string
func (*PresignDownloadResponse) Validate ¶
func (m *PresignDownloadResponse) Validate() error
Validate checks the field values on PresignDownloadResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*PresignDownloadResponse) ValidateAll ¶
func (m *PresignDownloadResponse) ValidateAll() error
ValidateAll checks the field values on PresignDownloadResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in PresignDownloadResponseMultiError, or nil if none found.
type PresignDownloadResponseMultiError ¶
type PresignDownloadResponseMultiError []error
PresignDownloadResponseMultiError is an error wrapping multiple validation errors returned by PresignDownloadResponse.ValidateAll() if the designated constraints aren't met.
func (PresignDownloadResponseMultiError) AllErrors ¶
func (m PresignDownloadResponseMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (PresignDownloadResponseMultiError) Error ¶
func (m PresignDownloadResponseMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type PresignDownloadResponseValidationError ¶
type PresignDownloadResponseValidationError struct {
// contains filtered or unexported fields
}
PresignDownloadResponseValidationError is the validation error returned by PresignDownloadResponse.Validate if the designated constraints aren't met.
func (PresignDownloadResponseValidationError) Cause ¶
func (e PresignDownloadResponseValidationError) Cause() error
Cause function returns cause value.
func (PresignDownloadResponseValidationError) Error ¶
func (e PresignDownloadResponseValidationError) Error() string
Error satisfies the builtin error interface
func (PresignDownloadResponseValidationError) ErrorName ¶
func (e PresignDownloadResponseValidationError) ErrorName() string
ErrorName returns error name.
func (PresignDownloadResponseValidationError) Field ¶
func (e PresignDownloadResponseValidationError) Field() string
Field function returns field value.
func (PresignDownloadResponseValidationError) Key ¶
func (e PresignDownloadResponseValidationError) Key() bool
Key function returns key value.
func (PresignDownloadResponseValidationError) Reason ¶
func (e PresignDownloadResponseValidationError) Reason() string
Reason function returns reason value.
type PresignUploadRequest ¶
type PresignUploadRequest struct {
// Bucket name where the file should be uploaded
BucketName string `protobuf:"bytes,1,opt,name=bucket_name,json=bucketName,proto3" json:"bucket_name,omitempty"`
// Content type of the file (e.g., "image/jpeg", "image/png", "image/webp")
ContentType string `protobuf:"bytes,2,opt,name=content_type,json=contentType,proto3" json:"content_type,omitempty"`
// Maximum allowed size of the file in bytes (will be enforced by storage)
MaxFileSize int64 `protobuf:"varint,3,opt,name=max_file_size,json=maxFileSize,proto3" json:"max_file_size,omitempty"`
// Optional: Path/Folder where the file should be uploaded (e.g., "users/avatars")
Path string `protobuf:"bytes,4,opt,name=path,proto3" json:"path,omitempty"`
// Optional: Exact filename to use. If not provided, a unique UUID will be generated.
FileName string `protobuf:"bytes,5,opt,name=file_name,json=fileName,proto3" json:"file_name,omitempty"`
// contains filtered or unexported fields
}
PresignUploadRequest contains the parameters for generating a presigned upload URL
func (*PresignUploadRequest) Descriptor
deprecated
func (*PresignUploadRequest) Descriptor() ([]byte, []int)
Deprecated: Use PresignUploadRequest.ProtoReflect.Descriptor instead.
func (*PresignUploadRequest) GetBucketName ¶
func (x *PresignUploadRequest) GetBucketName() string
func (*PresignUploadRequest) GetContentType ¶
func (x *PresignUploadRequest) GetContentType() string
func (*PresignUploadRequest) GetFileName ¶
func (x *PresignUploadRequest) GetFileName() string
func (*PresignUploadRequest) GetMaxFileSize ¶
func (x *PresignUploadRequest) GetMaxFileSize() int64
func (*PresignUploadRequest) GetPath ¶
func (x *PresignUploadRequest) GetPath() string
func (*PresignUploadRequest) ProtoMessage ¶
func (*PresignUploadRequest) ProtoMessage()
func (*PresignUploadRequest) ProtoReflect ¶
func (x *PresignUploadRequest) ProtoReflect() protoreflect.Message
func (*PresignUploadRequest) Reset ¶
func (x *PresignUploadRequest) Reset()
func (*PresignUploadRequest) String ¶
func (x *PresignUploadRequest) String() string
func (*PresignUploadRequest) Validate ¶
func (m *PresignUploadRequest) Validate() error
Validate checks the field values on PresignUploadRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*PresignUploadRequest) ValidateAll ¶
func (m *PresignUploadRequest) ValidateAll() error
ValidateAll checks the field values on PresignUploadRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in PresignUploadRequestMultiError, or nil if none found.
type PresignUploadRequestMultiError ¶
type PresignUploadRequestMultiError []error
PresignUploadRequestMultiError is an error wrapping multiple validation errors returned by PresignUploadRequest.ValidateAll() if the designated constraints aren't met.
func (PresignUploadRequestMultiError) AllErrors ¶
func (m PresignUploadRequestMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (PresignUploadRequestMultiError) Error ¶
func (m PresignUploadRequestMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type PresignUploadRequestValidationError ¶
type PresignUploadRequestValidationError struct {
// contains filtered or unexported fields
}
PresignUploadRequestValidationError is the validation error returned by PresignUploadRequest.Validate if the designated constraints aren't met.
func (PresignUploadRequestValidationError) Cause ¶
func (e PresignUploadRequestValidationError) Cause() error
Cause function returns cause value.
func (PresignUploadRequestValidationError) Error ¶
func (e PresignUploadRequestValidationError) Error() string
Error satisfies the builtin error interface
func (PresignUploadRequestValidationError) ErrorName ¶
func (e PresignUploadRequestValidationError) ErrorName() string
ErrorName returns error name.
func (PresignUploadRequestValidationError) Field ¶
func (e PresignUploadRequestValidationError) Field() string
Field function returns field value.
func (PresignUploadRequestValidationError) Key ¶
func (e PresignUploadRequestValidationError) Key() bool
Key function returns key value.
func (PresignUploadRequestValidationError) Reason ¶
func (e PresignUploadRequestValidationError) Reason() string
Reason function returns reason value.
type PresignUploadResponse ¶
type PresignUploadResponse struct {
// Presigned URL for uploading the file
PresignedUrl string `protobuf:"bytes,1,opt,name=presigned_url,json=presignedUrl,proto3" json:"presigned_url,omitempty"`
// Object key/path in storage
ObjectKey string `protobuf:"bytes,2,opt,name=object_key,json=objectKey,proto3" json:"object_key,omitempty"`
// Expiration time in seconds
ExpiresIn int32 `protobuf:"varint,3,opt,name=expires_in,json=expiresIn,proto3" json:"expires_in,omitempty"`
// Optional: Form data fields for POST upload (required for size enforcement)
FormData map[string]string `` /* 159-byte string literal not displayed */
// contains filtered or unexported fields
}
PresignUploadResponse contains the presigned URL and metadata
func (*PresignUploadResponse) Descriptor
deprecated
func (*PresignUploadResponse) Descriptor() ([]byte, []int)
Deprecated: Use PresignUploadResponse.ProtoReflect.Descriptor instead.
func (*PresignUploadResponse) GetExpiresIn ¶
func (x *PresignUploadResponse) GetExpiresIn() int32
func (*PresignUploadResponse) GetFormData ¶
func (x *PresignUploadResponse) GetFormData() map[string]string
func (*PresignUploadResponse) GetObjectKey ¶
func (x *PresignUploadResponse) GetObjectKey() string
func (*PresignUploadResponse) GetPresignedUrl ¶
func (x *PresignUploadResponse) GetPresignedUrl() string
func (*PresignUploadResponse) ProtoMessage ¶
func (*PresignUploadResponse) ProtoMessage()
func (*PresignUploadResponse) ProtoReflect ¶
func (x *PresignUploadResponse) ProtoReflect() protoreflect.Message
func (*PresignUploadResponse) Reset ¶
func (x *PresignUploadResponse) Reset()
func (*PresignUploadResponse) String ¶
func (x *PresignUploadResponse) String() string
func (*PresignUploadResponse) Validate ¶
func (m *PresignUploadResponse) Validate() error
Validate checks the field values on PresignUploadResponse with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.
func (*PresignUploadResponse) ValidateAll ¶
func (m *PresignUploadResponse) ValidateAll() error
ValidateAll checks the field values on PresignUploadResponse with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in PresignUploadResponseMultiError, or nil if none found.
type PresignUploadResponseMultiError ¶
type PresignUploadResponseMultiError []error
PresignUploadResponseMultiError is an error wrapping multiple validation errors returned by PresignUploadResponse.ValidateAll() if the designated constraints aren't met.
func (PresignUploadResponseMultiError) AllErrors ¶
func (m PresignUploadResponseMultiError) AllErrors() []error
AllErrors returns a list of validation violation errors.
func (PresignUploadResponseMultiError) Error ¶
func (m PresignUploadResponseMultiError) Error() string
Error returns a concatenation of all the error messages it wraps.
type PresignUploadResponseValidationError ¶
type PresignUploadResponseValidationError struct {
// contains filtered or unexported fields
}
PresignUploadResponseValidationError is the validation error returned by PresignUploadResponse.Validate if the designated constraints aren't met.
func (PresignUploadResponseValidationError) Cause ¶
func (e PresignUploadResponseValidationError) Cause() error
Cause function returns cause value.
func (PresignUploadResponseValidationError) Error ¶
func (e PresignUploadResponseValidationError) Error() string
Error satisfies the builtin error interface
func (PresignUploadResponseValidationError) ErrorName ¶
func (e PresignUploadResponseValidationError) ErrorName() string
ErrorName returns error name.
func (PresignUploadResponseValidationError) Field ¶
func (e PresignUploadResponseValidationError) Field() string
Field function returns field value.
func (PresignUploadResponseValidationError) Key ¶
func (e PresignUploadResponseValidationError) Key() bool
Key function returns key value.
func (PresignUploadResponseValidationError) Reason ¶
func (e PresignUploadResponseValidationError) Reason() string
Reason function returns reason value.
type UnimplementedMediabaseServiceServer ¶
type UnimplementedMediabaseServiceServer struct{}
UnimplementedMediabaseServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedMediabaseServiceServer) CreateBucket ¶
func (UnimplementedMediabaseServiceServer) CreateBucket(context.Context, *CreateBucketRequest) (*CreateBucketResponse, error)
func (UnimplementedMediabaseServiceServer) DeleteObject ¶
func (UnimplementedMediabaseServiceServer) DeleteObject(context.Context, *DeleteObjectRequest) (*DeleteObjectResponse, error)
func (UnimplementedMediabaseServiceServer) Ping ¶
func (UnimplementedMediabaseServiceServer) Ping(context.Context, *PingRequest) (*PingResponse, error)
func (UnimplementedMediabaseServiceServer) PresignDownload ¶
func (UnimplementedMediabaseServiceServer) PresignDownload(context.Context, *PresignDownloadRequest) (*PresignDownloadResponse, error)
func (UnimplementedMediabaseServiceServer) PresignUpload ¶
func (UnimplementedMediabaseServiceServer) PresignUpload(context.Context, *PresignUploadRequest) (*PresignUploadResponse, error)
type UnsafeMediabaseServiceServer ¶
type UnsafeMediabaseServiceServer interface {
// contains filtered or unexported methods
}
UnsafeMediabaseServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MediabaseServiceServer will result in compilation errors.